# Himena

[![PyPI - Version](https://img.shields.io/pypi/v/himena.svg)](https://pypi.org/project/himena)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/himena.svg)](https://pypi.org/project/himena)
[![codecov](https://codecov.io/gh/hanjinliu/himena/graph/badge.svg?token=7BS2gF92SL)](https://codecov.io/gh/hanjinliu/himena)

-----

![](images/window.png)

`himena` is an infinitely extensible and reusable applications framework for data
science.

### [&rarr; Documentation](https://hanjinliu.github.io/himena/)

## Installation

`himena` is available on PyPI.

```shell
pip install himena -U
```

Alternatively, you can install the latest version from GitHub.

```shell
git clone git+https://github.com/hanjinliu/himena
cd himena
pip install -e .
```

## Start application

```shell
himena
```

## Plugins

You can customize `himena` for your needs by installing plugins. Here's some example plugins:

- [himena-image](https://github.com/hanjinliu/himena-image): image processing and analysis
- [himena-stats](https://github.com/hanjinliu/himena-stats): statistical testing and modeling.
- [himena-seaborn](https://github.com/hanjinliu/himena-seaborn): [seaborn](https://github.com/mwaskom/seaborn) plotting.
